import unittest  # Core Python Test Framework

from .test_active_directory import *  # Testing Active Directory Authentication
from .test_totp import *  # Testing TOTP (Time-based OTP)
from .test_oauth2 import *  # Testing OAuth2 and OpenID Connect
from .test_saml import *  # Testing SAML SSO Authentication
from .test_user_management import *  # Testing User Management